# eric7.Testing.Interfaces.TestFrameworkRegistry

Module implementing a simple registry containing the available test framework interfaces.

### Global Attributes

None

### Classes

TestFrameworkRegistry | Class implementing a simple registry of test framework interfaces.

### Functions

None

## TestFrameworkRegistry

Class implementing a simple registry of test framework interfaces.

The test executor for a framework is responsible for running the tests, receiving the results and preparing them for display. It must implement the interface of TestExecutorBase.

Frameworks must first be registered using '.register()'. This registry can then create the assoicated test executor when '.createExecutor()' is called.

### Derived from

None

### Class Attributes

None

### Class Methods

None

### Methods

TestFrameworkRegistry | Constructor
createExecutor | Public method to create a test framework executor.
getFrameworks | Public method to get a copy of the registered frameworks.
register | Public method to register a test framework executor.

### Static Methods

None

#### TestFrameworkRegistry (Constructor)

TestFrameworkRegistry()

Constructor

#### TestFrameworkRegistry.createExecutor

createExecutor(framework, widget)

Public method to create a test framework executor.

Note: The executor classes have to be registered first.

framework (str)
  name of the test framework
widget (TestingWidget)
  reference to the unit test widget

Return:
  test framework executor object

Return Type:
  TestExecutorBase

#### TestFrameworkRegistry.getFrameworks

getFrameworks()

Public method to get a copy of the registered frameworks.

Return:
  copy of the registered frameworks

Return Type:
  dict

#### TestFrameworkRegistry.register

register(executorClass)

Public method to register a test framework executor.

executorClass (TestExecutorBase)
  class implementing the test framework executor

Up